@@ -23,35 +23,45 @@ launcher=
 helper_mode=4755
 makefile_target='$(RUTILT_NAME) $(HELPER_NAME)'
 kernel_sources_path='/lib/modules/'`uname -r`'/build/include/'
-options_base='-pipe -Wall -s'
-options="$options_base -O3 -DNDEBUG"
+cflags_base='-pipe -Wall'
+cflags=
 # Generated variables :
 rutilt_name=rutilt
 rutilt_prefix=bin/
 helper_name=rutilt_helper
-helper_prefix=share/rutilt/
+helper_prefix=bin/
 ip_script_name=set_ip.sh
-ip_script_prefix=share/rutilt/
+data_prefix=share/apps/rutilt/
+ip_script_prefix=$data_prefix
 helper_launcher_name=helper_launcher.sh
-helper_launcher_prefix=share/rutilt/
-user_config_name=/rutilt/
+helper_launcher_prefix=$data_prefix
+user_config_name=rutilt/
 user_config_prefix=/.config/
-icon_prefix=share/rutilt/
+# There's a distinction between menu icons and the other arts.
 tray_icon_disconnected_name=disconnected_tray.png
 tray_icon_low_name=low_tray.png
 tray_icon_medium_name=medium_tray.png
 tray_icon_high_name=high_tray.png
-options_name=RutilT_options.xml
-icon_prefix=share/pixmaps/rutilt/
+icons_prefix=share/icons/hicolor
+icons_suffix=apps
+icon_final_name=rutilt.png
 icon_16x16_name=RutilT16x16.png
 icon_32x32_name=RutilT32x32.png
 icon_48x48_name=RutilT48x48.png
 icon_64x64_name=RutilT64x64.png
 icon_128x128_name=RutilT128x128.png
+icon_16x16_prefix=$icons_prefix/16x16/$icons_suffix/
+icon_32x32_prefix=$icons_prefix/32x32/$icons_suffix/
+icon_48x48_prefix=$icons_prefix/48x48/$icons_suffix/
+icon_64x64_prefix=$icons_prefix/64x64/$icons_suffix/
+icon_128x128_prefix=$icons_prefix/128x128/$icons_suffix/
+options_name=RutilT_options.xml
 desktop_launcher_name=rutilt.desktop
 desktop_launcher_prefix=share/applications/
 man_name=rutilt.1
+man_helper_name=rutilt_helper.1
 man_prefix=share/man/man1
+version=v0.16
 #
 #
 # Parse options :
@@ -69,7 +79,9 @@ Used without arguments, default settings are applied. Arguments are :
     --prefix=PATH : Set PATH as file-system root for installation.
     --kernel_sources=PATH : Use the kernel sources located into PATH.
     --debug : Compile the program with debugging output enabled, and turn off
-              optimizations.
+              optimizations (unless --cflags is used).
+    --cflags=PARAMETERS : Pass PARAMETERS to the compiler.
+    --version=LABEL : Use LABEL as version label.
     --launcher=built-in | disabled | nopasswd | external : Set how the helper is
     launched as root and therefore how users' identity is checked :
         built-in : The default setting, use the built-in launcher, it implies
@@ -120,8 +132,20 @@ Used without arguments, default settings are applied. Arguments are :
 
          --debug)
             echo 'Enabling debugging output, turning optimizations off.'
-            options=$options_base
-            make clean_rutilt_secure_target_name;;
+            if [ -z "$cflags" ]; then
+                cflags="$cflags_base -g"
+            fi
+            if [ -e ./Makefile_cst ]; then
+                make clean_rutilt_secure_target_name
+            fi;;
+
+          --cflags)
+            echo "Using : \"$arg_value\" as compilation options."
+            cflags="$arg_value ";;
+
+          --version)
+            echo "Labelling RutilT : \"$arg_value\""
+            version=$arg_value;;
 
         *)
             echo "Invalid argument : $arg
@@ -129,6 +153,9 @@ Use \"./configure.sh --help\" for help."
             exit 1;;
     esac
 done
+if [ -z "$cflags" ]; then
+    cflags="$cflags_base -s -O3 -DNDEBUG"
+fi
 #
 #
 # Dependencies check :
@@ -173,35 +200,42 @@ fi
 # Makefile_cst :
 echo -n "Generating Makefile constants... "
 echo "# WARNING : Auto-generated file, edit with care.
-OPTIONS = $options
-PREFIX = $prefix
-KERNEL_SOURCES_PATH = $kernel_sources_path
-RUTILT_NAME = $rutilt_name
+CFLAGS := $cflags
+PREFIX := $prefix
+KERNEL_SOURCES_PATH := $kernel_sources_path
+RUTILT_NAME := $rutilt_name
 RUTILT_PREFIX = \$(PREFIX)/$rutilt_prefix
-HELPER_NAME = $helper_name
+HELPER_NAME := $helper_name
 HELPER_PREFIX = \$(PREFIX)/$helper_prefix
-HELPER_MODE = $helper_mode
+HELPER_MODE := $helper_mode
 HELPER_LAUNCHER_PREFIX = \$(PREFIX)/$helper_launcher_prefix
-HELPER_LAUNCHER_NAME = $helper_launcher_name
-IP_SCRIPT_NAME = $ip_script_name
+HELPER_LAUNCHER_NAME := $helper_launcher_name
+IP_SCRIPT_NAME := $ip_script_name
 IP_SCRIPT_PREFIX = \$(PREFIX)/$ip_script_prefix
-USER_CONFIG_NAME = $user_config_name
-USER_CONFIG_PREFIX = $user_config_prefix
-ICON_PREFIX = \$(PREFIX)/$icon_prefix
-TRAY_ICON_DISCONNECTED_NAME = $tray_icon_disconnected_name
-TRAY_ICON_LOW_NAME = $tray_icon_low_name
-TRAY_ICON_MEDIUM_NAME = $tray_icon_medium_name
-TRAY_ICON_HIGH_NAME = $tray_icon_high_name
-ICON_16X16_NAME = $icon_16x16_name
-ICON_32X32_NAME = $icon_32x32_name
-ICON_48X48_NAME = $icon_48x48_name
-ICON_64X64_NAME = $icon_64x64_name
-ICON_128X128_NAME = $icon_128x128_name
-DESKTOP_LAUNCHER = $desktop_launcher_name
+USER_CONFIG_NAME := $user_config_name
+USER_CONFIG_PREFIX := $user_config_prefix
+DATA_PREFIX = \$(PREFIX)/$data_prefix
+TRAY_ICON_DISCONNECTED_NAME := $tray_icon_disconnected_name
+TRAY_ICON_LOW_NAME := $tray_icon_low_name
+TRAY_ICON_MEDIUM_NAME := $tray_icon_medium_name
+TRAY_ICON_HIGH_NAME := $tray_icon_high_name
+ICON_16X16_NAME := $icon_16x16_name
+ICON_32X32_NAME := $icon_32x32_name
+ICON_48X48_NAME := $icon_48x48_name
+ICON_64X64_NAME := $icon_64x64_name
+ICON_128X128_NAME := $icon_128x128_name
+ICON_FINAL_NAME := $icon_final_name
+ICON_16X16_PREFIX = \$(PREFIX)/$icon_16x16_prefix
+ICON_32X32_PREFIX = \$(PREFIX)/$icon_32x32_prefix
+ICON_48X48_PREFIX = \$(PREFIX)/$icon_48x48_prefix
+ICON_64X64_PREFIX = \$(PREFIX)/$icon_64x64_prefix
+ICON_128X128_PREFIX = \$(PREFIX)/$icon_128x128_prefix
+DESKTOP_LAUNCHER := $desktop_launcher_name
 DESKTOP_LAUNCHER_PREFIX = \$(PREFIX)/$desktop_launcher_prefix
-RUTILT_MAN = $man_name
-RUTILT_MAN_PREFIX = \$(PREFIX)/$man_prefix
-BUILD = $makefile_target" > Makefile_cst
+RUTILT_MAN := $man_name
+HELPER_MAN := $man_helper_name
+MAN_PREFIX = \$(PREFIX)/$man_prefix
+BUILD := $makefile_target" > Makefile_cst
 echo done
 #
 #
@@ -228,16 +262,17 @@ $launcher
     const std::string HelperLauncherPath (\"$prefix/$helper_launcher_prefix$helper_launcher_name\");
     const std::string DhcpScriptPrefix (\"$prefix/$ip_script_prefix\");
     const std::string DhcpScriptName (\"$ip_script_name\");
-    const std::string TrayIconDisconnectedPath (\"$prefix/$icon_prefix$tray_icon_disconnected_name\");
-    const std::string TrayIconLowPath (\"$prefix/$icon_prefix$tray_icon_low_name\");
-    const std::string TrayIconMediumPath (\"$prefix/$icon_prefix$tray_icon_medium_name\");
-    const std::string TrayIconHighPath (\"$prefix/$icon_prefix$tray_icon_high_name\");
+    const std::string TrayIconDisconnectedPath (\"$prefix/$data_prefix$tray_icon_disconnected_name\");
+    const std::string TrayIconLowPath (\"$prefix/$data_prefix$tray_icon_low_name\");
+    const std::string TrayIconMediumPath (\"$prefix/$data_prefix$tray_icon_medium_name\");
+    const std::string TrayIconHighPath (\"$prefix/$data_prefix$tray_icon_high_name\");
     const std::string OptionsFileName (\"$options_name\");
-    const std::string Icon16Path (\"$prefix/$icon_prefix$icon_16x16_name\");
-    const std::string Icon32Path (\"$prefix/$icon_prefix$icon_32x32_name\");
-    const std::string Icon48Path (\"$prefix/$icon_prefix$icon_48x48_name\");
-    const std::string Icon64Path (\"$prefix/$icon_prefix$icon_64x64_name\");
-    const std::string Icon128Path (\"$prefix/$icon_prefix$icon_128x128_name\");
+    const std::string Icon16Path (\"$prefix/$icon_16x16_prefix$icon_final_name\");
+    const std::string Icon32Path (\"$prefix/$icon_32x32_prefix$icon_final_name\");
+    const std::string Icon48Path (\"$prefix/$icon_48x48_prefix$icon_final_name\");
+    const std::string Icon64Path (\"$prefix/$icon_64x64_prefix$icon_final_name\");
+    const std::string Icon128Path (\"$prefix/$icon_128x128_prefix$icon_final_name\");
+    const std::string VersionLabel (\"$version\");
 
 } // namespace nsCore
 
@@ -245,22 +280,25 @@ $launcher
 echo done
 #
 #
+# Icon=$prefix/$icon_prefix$icon_48x48_name
 # rutilt.desktop
 echo -n "Generating desktop launcher... "
 echo "[Desktop Entry]
 Name=RutilT WLAN Manager
 Name[fr]=Utilitaire de Configuration Wifi RutilT
+Name[it]=Strumento di Configurazione WiFi RutilT
 GenericName=WLAN Manager
 GenericName[fr]=Utilitaire de Configuration Wifi
+GenericName[it]=Strumento di Configurazione WiFi
 Comment=Manage your wireless network interfaces
 Comment[fr]=Configurer vos cartes Wifi
+Comment[it]=Configura le tue schede WiFi
 Terminal=false
 Type=Application
-Encoding=UTF-8
-Categories=GTK;System;Settings;Application;Network
-Version=0.14
+Categories=GTK;System;Settings;Network;
+Version=1.0
 StartupNotify=false
-Icon=$prefix/$icon_prefix$icon_64x64_name
+Icon=$icon_final_name
 Exec=$rutilt_name" > $desktop_launcher_name
 echo done
 #
