@@ -34,7 +34,7 @@ namespace nsGUI
 {
     class CGtkGUI;
 
-    typedef bool (CGtkGUI::*GUICallBack) ();
+    typedef bool (CGtkGUI::*GUICallBack) (unsigned);
 
 
         // A graphic component, the first column is always a button.
