@@ -28,7 +28,6 @@
 extern "C"{
 #include <gtk/gtk.h>
 }
-
 #if !GTK_CHECK_VERSION (2, 6, 0)
 #error Invalid GTK+ headers, require at least version 2.6.
 #endif
@@ -82,15 +81,15 @@ namespace nsGUI
 
         void Run (const nsCore::CCLIOpt&) throw (nsErrors::CException);
 
-        bool Connect () throw();
+        bool Connect (unsigned) throw();
         void Scan () throw();
         void StopScanning () throw();
 
-        bool ApplyProfile () throw();
-        bool DeleteProfile () throw();
+        bool ApplyProfile (unsigned) throw();
+        bool DeleteProfile (unsigned) throw();
         const nsUserData::CProfile* EditProfile () throw();
         const nsUserData::CProfile* NewProfile () throw();
-        const void NewProfile (unsigned) throw();
+        bool NewProfile (unsigned) throw();
         void RefreshRates () throw();
         bool BecomeRoot () throw (nsErrors::CException);
         bool IsRoot () const throw();
@@ -103,65 +102,69 @@ namespace nsGUI
         operator ::GtkWindow* () throw();
 
 
-      protected :
-        bool FillCell (nsWireless::CCell& Cell) throw();
-        void SelectMatchingProfile (const nsWireless::CCell&) throw();
-        bool ChangeModule (const std::string& = std::string())
-                                                throw (nsErrors::CException);
-        void SelectCurrentCell () throw (nsErrors::CSystemExc);
-        void SelectCurrentCell (const nsWireless::CMacAddress&) throw();
-        void SetIPFromProfile () throw (nsErrors::CException);
-        void RefreshLinkStatus () throw (nsErrors::CException);
-        /** \param unsigned The TX rate in Mbps. */
-        void RefreshLinkStatus (const nsWireless::CQuality&, unsigned,
-                                const nsWireless::CMacAddress&)
-                                                throw(nsErrors::CException);
-        bool RefreshStats () throw();
-        /** \param unsigned The TX rate in Mbps. */
-        void RefreshTray (const nsWireless::CQuality&, unsigned) throw();
-        void LoadOptions () throw();
-        void StoreData () throw (nsErrors::CException);
-
-
       private :
         CGtkGUI& operator= (const CGtkGUI&);
         CGtkGUI (const CGtkGUI&);
 
         void SetNoRoot () throw();
+        void SetRoot () throw();
         void SetWindowIcons () throw();
-
-        std::auto_ptr<nsCore::IModule> m_pModule;
-        ::GtkWindow* const m_pWindow;
-        ::GtkNotebook* const m_pNoteBook;
+        unsigned CreateProfile (unsigned CellNum) throw();
+        void SelectMatchingProfile (const nsWireless::CCell&) throw();
+        void SelectMatchingProfile (unsigned ProfileI) throw();
+        bool ChangeModule (const std::string& = std::string())
+                                                throw (nsErrors::CException);
+        void SelectCurrentCell () throw (nsErrors::CSystemExc);
+        void SelectCurrentCell (const nsWireless::CMacAddress&) throw();
+        void SetIPFromProfile (unsigned ProfileI) throw (nsErrors::CException);
+        void RefreshLinkStatus () throw (nsErrors::CException);
+        /** \param unsigned The TX rate in Mbps. */
+        void RefreshLinkStatus (const nsWireless::CQuality&, unsigned,
+                                const nsWireless::CMacAddress&)
+                                                throw (nsErrors::CException);
+        bool RefreshStats () throw();
+        /** \param unsigned The TX rate in Mbps. */
+        void RefreshTray (const nsWireless::CQuality&, unsigned) throw();
+        void LoadOptions () throw();
+        void StoreData () throw (nsErrors::CException);
+        bool IsIgnored () const throw();
+        void IsIgnored (bool) throw();
+        bool IsStatsAvailable () const throw();
+        void IsStatsAvailable (bool) throw();
+        bool BringIfaceUp () throw();
+        void IfaceIsDown () throw();
+        void TrayIconMenu (::GdkEventButton&) throw();
+        ::GtkWidget* MakeMenuVisibilityItem () throw();
+        ::GtkWidget* MakeMenuProfileItem() throw();
+        ::GtkWidget* MakeMenuExitItem() throw();
 
         enum PageNum_e {LinkStatus, Stats, Profiles, SiteSurvey, Preferences,
                         Private};
 
+        enum {IsRootF = 1, IsIgnoredF = 2, IsStatsAvailableF = 4};
+
+        std::auto_ptr<nsCore::IModule> m_pModule;
+        ::GtkWindow* const m_pWindow;
+        ::GtkNotebook* const m_pNoteBook;
             // I use this because C++ exception can't go through gtk.
         nsErrors::CException m_Exc;
-
-        bool m_IsRoot;
-
         CLinkStatusTab m_LinkStatusTab;
-
         unsigned m_GlobalTimer;
-
         CStatsPage m_StatsPage;
         std::auto_ptr<nsNet::CInterface> m_pIface;
-
         CSiteSurveyTab m_SiteSurveyTab;
         CellVec_t m_CellVec;
         unsigned m_SiteSurveyTabTimer;
         unsigned m_TimeRemaining;
-
         CProfileTab m_ProfileTab;
         CTrayIcon m_TrayIcon;
         std::string m_ToolTipHeader;
+        unsigned char m_Flags;
         CPrefsPage m_PrefsPage;
-        bool m_IsIgnored;
         unsigned m_LeaveRootModeTimer;
         unsigned m_CurrentRateIndex;
-        bool m_StatsAvailable;
+        ::GtkMenuShell* m_pTrayMenu;
+        ::gulong m_ExitHandlerID;
 
 
         static int DeleteCallBack (::GtkWidget*, ::GdkEvent*, void*) throw();
@@ -179,6 +182,11 @@ namespace nsGUI
         static void RateChangedCallBack (CGtkGUI*) throw();
         static bool RefreshRateDelayedCallBack (CGtkGUI*) throw();
         static void DisplayTrayIconButtonCallBack (CGtkGUI*) throw();
+        static void IfaceStatusChangedCallBack (CGtkGUI*) throw();
+        static void HideCallBack (CGtkGUI*) throw();
+        static void ShowCallBack (CGtkGUI*) throw();
+        static void CreateProfileAndApplyCallBack (CGtkGUI*) throw();
+        static void ApplyProfileTrayCallBack (::gpointer) throw();
 
     }; // CGtkGUI
 
