@@ -22,6 +22,7 @@
 #include <cstring> // strcmp()
 
 #include "PrefsPage.h"
+#include "StaticSettings.h"
 
 
 
@@ -50,11 +51,8 @@ namespace
 
 
 
-const char* const nsGUI::CPrefsPage::DontLeaveRootMode ("Disabled");
-
-
 nsGUI::CPrefsPage::CPrefsPage (bool IsRoot) throw()
-    : m_pTable (GTK_TABLE (::gtk_table_new (5, 2, true))),
+    : m_pTable (GTK_TABLE (::gtk_table_new (6, 2, true))),
       m_pStartMinimizedButton (GTK_CHECK_BUTTON
               (::gtk_check_button_new_with_label ("Start hidden in tray"))),
       m_pAboutButton (GTK_BUTTON (::gtk_button_new_from_stock
@@ -67,7 +65,9 @@ nsGUI::CPrefsPage::CPrefsPage (bool IsRoot) throw()
       m_pRatesLabel (::gtk_label_new ("Maximum Tx rate")),
       m_NbRate (0), m_pRatesBox (GTK_COMBO_BOX (::gtk_combo_box_new_text())),
       m_pTrayIconButton (GTK_CHECK_BUTTON
-              (::gtk_check_button_new_with_label ("Display the tray icon")))
+              (::gtk_check_button_new_with_label ("Display tray icon"))),
+      m_pIfaceStatusButton (GTK_TOGGLE_BUTTON (::gtk_toggle_button_new())),
+      m_pIfaceLabel (GTK_LABEL (::gtk_label_new (0)))
 {
     BuildUI (IsRoot);
 
@@ -80,27 +80,34 @@ void nsGUI::CPrefsPage::BuildUI (bool IsRoot) throw()
     ::gtk_table_set_col_spacings (m_pTable, 12);
     ::gtk_table_set_row_spacings (m_pTable, 8);
 
-    ::gtk_table_attach_defaults (m_pTable, m_pRatesLabel, 0, 1, 0, 1);
-    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pRatesBox), 1, 2, 0, 1,
+    ::gtk_container_add (GTK_CONTAINER (m_pIfaceStatusButton),
+                         GTK_WIDGET (m_pIfaceLabel));
+    ::gtk_table_attach_defaults (m_pTable, ::gtk_label_new ("The interface is"
+                                                " currently : "), 0, 1, 0, 1);
+    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pIfaceStatusButton), 1, 2, 0, 1,
+                        GTK_EXPAND, GTK_EXPAND, 0, 0);
+
+    ::gtk_table_attach_defaults (m_pTable, m_pRatesLabel, 0, 1, 1, 2);
+    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pRatesBox), 1, 2, 1, 2,
                         GTK_FILL, GTK_SHRINK, 0, 0);
 
     ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pTrayIconButton), 0, 1,
-                        1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
+                        2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
     ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pStartMinimizedButton),
-                        1, 2, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
+                        1, 2, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
 
-    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pChangeInterface), 0, 1, 2, 3,
+    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pChangeInterface), 0, 1, 3, 4,
                         GTK_EXPAND, GTK_EXPAND, 0, 0);
-    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pRootModeButton), 1, 2, 2, 3,
+    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pRootModeButton), 1, 2, 3, 4,
                         GTK_EXPAND, GTK_EXPAND, 0, 0);
 
     ::GtkWidget* const pLabel (::gtk_label_new
                                             ("Leave priviliged mode after"));
-    ::gtk_table_attach_defaults (m_pTable, pLabel, 0, 1, 3, 4);
+    ::gtk_table_attach_defaults (m_pTable, pLabel, 0, 1, 4, 5);
     ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pLeaveRootModeBox),
-                        1, 2, 3, 4, GTK_FILL, GTK_SHRINK, 0, 0);
+                        1, 2, 4, 5, GTK_FILL, GTK_SHRINK, 0, 0);
     
-    ::gtk_combo_box_append_text (m_pLeaveRootModeBox, DontLeaveRootMode);
+    ::gtk_combo_box_append_text (m_pLeaveRootModeBox, "Disabled");
     for (unsigned i (0) ; i < NbDelay ; ++i)
     {
         std::ostringstream Os;
@@ -108,7 +115,7 @@ void nsGUI::CPrefsPage::BuildUI (bool IsRoot) throw()
         ::gtk_combo_box_append_text (m_pLeaveRootModeBox, Os.str().c_str());
     }
 
-    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pAboutButton), 0, 2, 4, 5,
+    ::gtk_table_attach (m_pTable, GTK_WIDGET (m_pAboutButton), 0, 2, 5, 6,
                         GTK_EXPAND, GTK_EXPAND, 0, 0);
 
     ::g_signal_connect (G_OBJECT (m_pAboutButton), "clicked",
@@ -126,16 +133,20 @@ void nsGUI::CPrefsPage::BuildUI (bool IsRoot) throw()
 } // BuildUI()
 
 
-void nsGUI::CPrefsPage::AboutButtonClicked (::GtkButton*, CPrefsPage*) throw()
+void nsGUI::CPrefsPage::AboutButtonClicked (::GtkButton*, CPrefsPage* This)
+                                                                        throw()
 {
     ::GtkAboutDialog* const m_pAboutDialog (GTK_ABOUT_DIALOG
                                                 (::gtk_about_dialog_new()));
+    ::gtk_window_set_transient_for (GTK_WINDOW (m_pAboutDialog),
+         GTK_WINDOW (::gtk_widget_get_toplevel (GTK_WIDGET (This->m_pTable))));
     ::gtk_about_dialog_set_name (m_pAboutDialog, "RutilT");
-    ::gtk_about_dialog_set_version (m_pAboutDialog, "v0.15");
+    ::gtk_about_dialog_set_version (m_pAboutDialog,
+                                                nsCore::VersionLabel.c_str());
     ::gtk_about_dialog_set_copyright (m_pAboutDialog,
                                       "Copyright © 2005-2007 Romain BONDUE");
     ::gtk_about_dialog_set_comments (m_pAboutDialog, "Wireless devices"
-            " configuration tool, with extra support for Ralink devices.");
+            " configuration tool\n with extra support for Ralink devices.");
     ::gtk_about_dialog_set_license (m_pAboutDialog,
 "This program is free software; you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
@@ -157,7 +168,8 @@ void nsGUI::CPrefsPage::AboutButtonClicked (::GtkButton*, CPrefsPage*) throw()
                               "Contributors :", "Neil Armstrong",
                               "Nicolas Favre-Félix", "Szymon Dziok",
                               "Vincent Stehlé", "Kirk Williams",
-                              "Alessandro Grechi - AleXit", "",
+                              "Alessandro Grechi - AleXit", "Cesare Tirabassi",
+                              "Misha Aizatulin", "Ben Hutchings", "",
                               "And thanks to the people who sent feedbacks,",
                               "bug reports and/or helped testing.", 0};
     ::gtk_about_dialog_set_authors (m_pAboutDialog, Authors);
@@ -220,7 +232,7 @@ unsigned nsGUI::CPrefsPage::GetAutoLeaveRootDelay () const throw()
                                                         (m_pLeaveRootModeBox));
 
     unsigned Delay (0);
-    if (strcmp (DelayStr, DontLeaveRootMode))
+    if (DelayStr)
     {
         std::istringstream Is (DelayStr);
         Is >> Delay;
@@ -246,9 +258,13 @@ void nsGUI::CPrefsPage::SetAutoLeaveRootDelay (unsigned Delay) throw()
 
 int nsGUI::CPrefsPage::GetSelectedRate () const throw()
 {
-    float Rate;
-    std::istringstream Is (::gtk_combo_box_get_active_text (m_pRatesBox));
-    Is >> Rate;
+    float Rate (0.F);
+    const char* const Text (::gtk_combo_box_get_active_text (m_pRatesBox));
+    if (Text)
+    {
+        std::istringstream Is (Text);
+        Is >> Rate;
+    }
     return int (Rate * 1000);
 
 } // GetSelectedRate()
