@@ -35,7 +35,7 @@ namespace
         std::istringstream Is (Str);
         T Value;
         Is >> Value;
-        if (Is || Is.eof()) return Value;
+        if (Is) return Value;
         throw nsErrors::CException ("Invalid data read (from helper).",
                                     nsErrors::InvalidDataFromHelper);
 
