@@ -35,6 +35,7 @@ extern "C"{
 #include "NetTools.h"
 #include "UserData.h"
 #include "IDriver.h"
+#include "StaticSettings.h"
 
 
 
@@ -118,7 +119,8 @@ int main (int argc, char* argv [])
 "All Gtk+ specific options are also supported, see the Gtk+ documentation."
                       << std::endl;
         else if (Opt.Version())
-            std::cout << "RutilT v0.15\nCopyright (C) 2005-2007 Romain BONDUE\n"
+            std::cout << "RutilT " << nsCore::VersionLabel
+                      << "\nCopyright (C) 2005-2007 Romain BONDUE\n"
 "This is free software.  You may redistribute copies of it under the terms of\n"
 "the GNU General Public License <http://www.gnu.org/licenses/gpl.html>.\n"
 "There is NO WARRANTY, to the extent permitted by law.\n\n"
