@@ -31,6 +31,7 @@
 extern "C"{
 #include <glib.h>
 #include <sys/stat.h> // ::chmod()
+#include <pwd.h>
 }
 
 #include "UserData.h"
@@ -53,10 +54,37 @@ namespace
     const char* const ProfileEncryptionDefaultKey ("DefaultKey");
     const char* const ProfileIPSettings ("IPSettings");
     const char* const ProfileIPSettingsHow ("How");
-        // This variable is a work-around for g++-3.3.
-    const std::string HomeDirectory (getenv ("HOME"));
-    const std::string ConfigDirectory (HomeDirectory + '/' +
-                                       nsCore::UserConfigPrefix);
+
+
+
+    std::string GetHomeDir () throw()
+    {
+        std::string HomeDir (::getenv("HOME"));
+#ifndef NDEBUG
+        std::cerr << "Home directory from environment : " << HomeDir
+                  << std::endl;
+#endif // NDEBUG
+        if (HomeDir.size() < 2U) // Couldn't get something useful.
+        {
+#ifndef NDEBUG
+            std::cerr << "Fetching home directory from passwd : ";
+#endif // NDEBUG
+            const ::passwd* const pData (::getpwuid(::getuid()));
+            if (pData)
+            {
+#ifndef NDEBUG
+                std::cerr << "success, got : " << pData->pw_dir << std::endl;
+#endif // NDEBUG
+                HomeDir = pData->pw_dir;
+            }
+#ifndef NDEBUG
+            else
+                std::cerr << "failed." << std::endl;
+#endif // NDEBUG
+        }
+        return HomeDir;
+
+    } // GetHomeDir()
 
 
     std::string Normalize (const std::string& Str) throw()
@@ -70,6 +98,15 @@ namespace
 
     } // Normalize()
 
+
+
+        // This variable is a work-around with g++-3.3.
+    const std::string HomeDirectory (GetHomeDir());
+    const std::string ConfigDirectory (HomeDirectory +
+                                                    nsCore::UserConfigPrefix);
+    const std::string ProfilesFilePath (ConfigDirectory +
+                            nsCore::UserConfigName + "RutilT_profiles.xml");
+
 } // anonymous namespace
 
 
@@ -99,35 +136,50 @@ nsUserData::CProfile::CProfile (const std::string& Name,
                                                         throw (std::bad_alloc)
     : m_Name (Name), m_SSID (Cell.GetSSID()),
       m_Mode (nsWireless::GetMatchingMode (Cell.GetMode())),
-      m_Channel (Cell.GetChannel()), m_EncryptionD (Cell.GetEncryptionD()) {}
+      m_Channel (Cell.GetChannel()), m_EncryptionD (Cell.GetEncryptionD()),
+      m_IPSettings (Dhcp)
+{
+    if (Cell.GetEncryptionD().GetEncrypt() == nsWireless::TKIPAES)
+        m_EncryptionD.SetEncrypt (nsWireless::AES);
+
+} // CProfile()
 
 
 bool nsUserData::CProfile::Match (const nsWireless::CCell& Cell) const throw()
 {
-    return m_Mode == Cell.GetMode() && m_Channel == Cell.GetChannel() &&
-           m_SSID == Cell.GetSSID() &&
+    return m_Mode == nsWireless::GetMatchingMode (Cell.GetMode()) &&
+           m_Channel == Cell.GetChannel() && m_SSID == Cell.GetSSID() &&
            m_EncryptionD.GetAuth() == Cell.GetEncryptionD().GetAuth() &&
            m_EncryptionD.GetEncrypt() == Cell.GetEncryptionD().GetEncrypt();
 
 } // Match()
 
 
-const char* const nsUserData::CProfilesFileBase::Indentation ("    ");
+const char* const nsUserData::CProfilesFile::Indentation ("    ");
 
 
-nsUserData::CProfilesFileBase::CProfilesFileBase
-                    (const std::string& FileName) throw (nsErrors::CSystemExc)
-    : m_FileName (AppDirectory + Normalize (FileName)) {MakeAppDirectory();}
+nsUserData::CProfilesFile::CProfilesFile () throw (nsErrors::CSystemExc)
+{
+    MakeAppDirectory();
+
+} // CProfilesFile()
 
 
-const char* nsUserData::CProfilesFileBase::GetRootMarkupLabel () const throw()
+const char* nsUserData::CProfilesFile::GetRootMarkupLabel () const throw()
 {
     return "Profile";
 
 } // GetRootMarkupLabel()
 
 
-void nsUserData::CProfilesFileBase::RecordFields (std::ostream& Os,
+void nsUserData::CProfilesFile::Extract () throw (nsErrors::CException)
+{
+    CXMLParser::Extract (ProfilesFilePath);
+
+} // Extract()
+
+
+void nsUserData::CProfilesFile::RecordFields (std::ostream& Os,
                                                   unsigned Pos)
                                                 throw (std::ios_base::failure)
 {
@@ -171,12 +223,12 @@ void nsUserData::CProfilesFileBase::RecordFields (std::ostream& Os,
 } // RecordFields()
 
 
-void nsUserData::CProfilesFileBase::Record () throw (nsErrors::CException)
+void nsUserData::CProfilesFile::Record () throw (nsErrors::CException)
 {
 #ifndef NDEBUG
-    std::cerr << "Recording profiles in : " << m_FileName << std::endl;
+    std::cerr << "Recording profiles in : " << ProfilesFilePath << std::endl;
 #endif
-    std::ofstream Os (m_FileName.c_str(), std::ios_base::trunc);
+    std::ofstream Os (ProfilesFilePath.c_str(), std::ios_base::trunc);
     try
     {
         Os.exceptions (std::ios_base::badbit | std::ios_base::failbit);
@@ -199,17 +251,17 @@ void nsUserData::CProfilesFileBase::Record () throw (nsErrors::CException)
                                     nsErrors::ProfilesRecordFailure);
     }
         // Keys are stored in this file, this is the least I can do...
-    if (::chmod (m_FileName.c_str(), 00600))
+    if (::chmod (ProfilesFilePath.c_str(), 00600))
     {
         std::ostringstream Os;
-        Os << "Can't set permission on file : " << m_FileName << '.';
+        Os << "Can't set permission on file : " << ProfilesFilePath << '.';
         throw nsErrors::CSystemExc (Os.str());
     }
 
 } // Record()
 
 
-void nsUserData::CProfilesFileBase::StartElement (const char* ElementName,
+void nsUserData::CProfilesFile::StartElement (const char* ElementName,
                                                   const char** AttributesNames,
                                               const char** AttributesValues)
                                    throw (std::bad_alloc, nsErrors::CException)
@@ -227,12 +279,12 @@ void nsUserData::CProfilesFileBase::StartElement (const char* ElementName,
 } // StartElement()
 
 
-void nsUserData::CProfilesFileBase::EndElement (const char* ElementName)
-                                                throw (nsErrors::CException)
+void nsUserData::CProfilesFile::EndElement (const char* ElementName)
+                                                    throw (nsErrors::CException)
 {     // Here we check if we have everything required.
     if (!strcmp (ElementName, GetRootMarkupLabel()))
     {
-        CProfile& Profile (GetProfile (Size() - 1));
+        CProfile& Profile (m_Profiles.back());
         if (Profile.GetMode() == nsWireless::Unknown)
             throw nsErrors::CException ("Missing mode.",
                                    nsErrors::ProfilesExtractionMissingMode);
@@ -244,14 +296,13 @@ void nsUserData::CProfilesFileBase::EndElement (const char* ElementName)
 } // EndElement()
 
 
-void nsUserData::CProfilesFileBase::Text (const char* ElementName,
-                                          const std::string& Text)
-                                                throw (nsErrors::CException)
+void nsUserData::CProfilesFile::Text (const char* ElementName,
+                        const std::string& Text) throw (nsErrors::CException)
 {
         // FIXME HORRIBLE... *Shocked*
     static unsigned Cnt (0);
 
-    CProfile& Profile (GetProfile (Size() - 1));
+    CProfile& Profile (m_Profiles.back());
     if (!strcmp (ElementName, ProfileSSID))
         Profile.SetSSID (Text);
     else if (!strcmp (ElementName, ProfileMode))
