@@ -40,10 +40,12 @@ case $2 in
 # No known essid, fallback on DHCP  but first kill any previously running
 # dhcp client :
     *) if [ -e /sbin/dhclient ]; then
-           kill `ps -o pid= -C"dhclient $1"`
+           pkill -f "dhclient $1"
            exec /sbin/dhclient $1
+       else if [ -e /sbin/dhcpcd ]; then
+           pkill -f "dhcpcd $1"
+           exec /sbin/dhcpcd $1
        else
-           kill `ps -o pid= -C"dhcpd $1"`
-           exec /sbin/dhcpd $1
-       fi;;
+           echo "set_ip.sh : Cannot find a dhcp client."
+       fi fi;;
 esac
